These functions are no longer used by Policy Sentry directly, but they have proven to be particularly useful as a library - so we left them here.

If you are interested in the analysis function - please check out [Parliament](https://github.com/duo-labs/parliament) by Scott Piper and Duo Labs.

